# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaTable(Component):
    """An AnyaTable component.
An Ant Design Table component
See https://ant.design/components/table

Keyword arguments:

- id (string; optional):
    The ID used to identify this component.

- bordered (boolean; optional):
    Bordered.

- cellUpdateOptimize (boolean; default True):
    Whether to allow cell content rendering.

- className (string | dict; optional):
    CSS classes to be added to the component.

- columns (list of dicts; optional):
    Columns.

    `columns` is a list of dicts with keys:

    - align (a value equal to: 'left', 'center', 'right'; optional)

    - className (dict; optional)

    - colSpan (number; optional)

    - colSpanRow (dict; optional)

    - dataIndex (string; required)

    - ellipsis (boolean | number | string | dict | list; optional)

    - filterResetToDefaultFilteredValue (boolean; optional)

    - fixed (a value equal to: 'left', 'right'; optional)

    - group (string | list of strings; optional)

    - hidden (boolean; optional)

    - key (string; optional)

    - onCell (boolean | number | string | dict | list; optional)

    - render (boolean | number | string | dict | list; optional)

    - renderOptions (dict; optional)

        `renderOptions` is a dict with keys:

        - renderType (a value equal to: 'row-merge'; optional)

    - rowSpan (dict; optional)

    - sorter (boolean | number | string | dict | list; optional)

    - title (a list of or a singular dash component, string or number; required)

    - width (number | string; optional)

- data (list of dicts; optional):
    Column data.

    `data` is a list of dicts with strings as keys and values of type
    list of boolean | number | string | dict | lists | a list of or a
    singular dash component, string or number | string | number | dict
    with keys:

    - content (number | string; optional)

    - key (string; optional)

    - rowSpan (number; optional)

- maxHeight (number; optional):
    Set max height.

- maxWidth (number; optional):
    Set max width.

- pagination (dict; default {    defaultPageSize: 20,    hideOnSinglePage: True,    showSizeChanger: False}):
    Config of pagination. You can ref table pagination config or full
    pagination document, hide it by setting it to False.

    `pagination` is a dict with keys:

    - current (number; optional)

    - disabled (boolean; optional)

    - hideOnSinglePage (boolean; optional)

    - pageSize (number; optional)

    - pageSizeOptions (list of numbers; optional)

    - position (a value equal to: 'topLeft', 'topCenter', 'topRight', 'bottomLeft', 'bottomCenter', 'bottomRight'; optional)

    - showQuickJumper (boolean; optional)

    - showSizeChanger (boolean; optional)

    - showTotal (boolean; optional)

    - showTotalPrefix (string; optional)

    - showTotalSuffix (string; optional)

    - simple (boolean; optional)

    - size (a value equal to: 'default', 'small'; optional)

    - total (number; optional) | boolean | dict

- size (a value equal to: 'small', 'default', 'large'; default 'small'):
    Size.

- style (dict; optional):
    Inline CSS style."""
    _children_props = ['columns[].title', 'data[]{}']
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaTable'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, columns=Component.UNDEFINED, data=Component.UNDEFINED, bordered=Component.UNDEFINED, maxHeight=Component.UNDEFINED, maxWidth=Component.UNDEFINED, size=Component.UNDEFINED, pagination=Component.UNDEFINED, cellUpdateOptimize=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bordered', 'cellUpdateOptimize', 'className', 'columns', 'data', 'maxHeight', 'maxWidth', 'pagination', 'size', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bordered', 'cellUpdateOptimize', 'className', 'columns', 'data', 'maxHeight', 'maxWidth', 'pagination', 'size', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaTable, self).__init__(**args)
